# cp4icl
Conformal Prediction for In-Context Learning


This repository will host implementations of conformal methods for
in-context learning, including CAOS and SCOS.

Initial release forthcoming.

